@@ -1,7 +1,13 @@
+# -*- coding: utf-8 -*-
+
+import re
 from datetime import datetime
 
 from CGPCLI.Errors import NotValidCGPStringError
 
+lbr_check_regex = re.compile(r"\".*\(.*\"", re.DOTALL)
+rbr_check_regex = re.compile(r"\".*\).*\"", re.DOTALL)
+
 def parse_to_CGP_object(python_object):
     result = ''
     
@@ -24,16 +30,10 @@ def parse_to_CGP_object(python_object):
 
 def parse_to_python_object(string, from_CLI=True):
     def preparse_from_CLI(string):
-        return string.replace('\n', '')  
+        return string.replace('\n', '')
     
     def parse_array(string):
-        result_arr = list()
-        values = string[1:-1]
-        
-        pos = values.find(',')
-        
-        while pos != -1:            
-            el = values[:pos]
+        def quotes_check(el, pos, values):
             while el.count('"')%2 != 0:
                 pos = values.find(',', pos+1)
                 if pos == -1:
@@ -41,10 +41,41 @@ def parse_to_python_object(string, from_CLI=True):
                     values = ''
                 else:
                     el = values[:pos]
-    
-            while el.count('(') != el.count(')'):
+            
+            return el, pos, values
+                    
+        def brackets_check(el, pos, values):
+            lb_counter = el.count('(')
+            rb_counter = el.count(')')
+            
+            while lb_counter != rb_counter:
                 pos = values.find(')', pos+1)
-                el = values[:pos + 1]
+                if pos == -1:
+                    el = el[:]
+                else:
+                    el = values[:pos + 1]
+
+                lb_counter = el.count('(')
+                rb_counter = el.count(')')
+                
+                if lbr_check_regex.match(el):
+                    lb_counter -= 1
+                if rbr_check_regex.match(el):
+                    rb_counter -= 1
+                    
+            return el, pos, values
+                    
+        result_arr = list()
+        values = string[1:-1]
+        
+        pos = values.find(',')
+        
+        while pos != -1:            
+            el = values[:pos]  
+           
+            el, pos, values = quotes_check(el, pos, values)
+            el, pos, values = brackets_check(el, pos, values)
+            el, pos, values = quotes_check(el, pos, values)        
                 
             result_arr.append(parse_to_python_object(el.strip()))
             
